import java.util.*;

public class VinValidator 
{
	static int r;
	static int c;
	static int intersectionPointCount;
	static char[][] board;
	
	public static void main(String[] args) throws Exception
	{
		Scanner scan = new Scanner(System.in);
		
		r = scan.nextInt();
		c = scan.nextInt();
		
		if (r < 7 || c < 7 ||  r > 100 || c > 100)
		{
			throw new Exception("# of rows or columns is out of bounds");
		}
		
		board = new char[r][c];
		
		for (int i = 0; i < r; i++)
		{
			String row = scan.next();
			if (row.length() != c)
			{
				throw new Exception("Something wrong with row " + (i + 1));
			}
			
			for (int j = 0; j < c; j++)
			{
				board[i][j] = row.charAt(j);
				if (board[i][j] != 'X' && board[i][j] != '.' && board[i][j] != 'A' && board[i][j] != 'B')
				{
					throw new Exception("Found an invalid character at <" + i + ", " + j + ">");
				}
			}
		}
		
		scan.close();
		
		// Verify one A and one B. Actual solutions will confirm they're on different loops
		
		int ACount = 0;
		int BCount = 0;
		for (int i = 0; i < r; i++)
		{
			for (int j = 0; j < c; j++)
			{
				if (board[i][j] == 'A')
				{
					ACount++;
				}

				if (board[i][j] == 'B')
				{
					BCount++;
				}
			}
		}
		
		if (ACount != 1 || BCount != 1)
		{
			throw new Exception("Incorrect number of As or Bs");
		}
		
		// Verify every X/A/B position is horizontally/vertically adjacent to exactly two Xs,
		// except for intersection point Xs which should be adjacent to exactly 4 other Xs
		
		for (int i = 0; i < r; i++)
		{
			for (int j = 0; j < c; j++)
			{
				if (board[i][j] == 'A' || board[i][j] == 'B')
				{
					AssertExactlyTwoAdjacentXs(i, j);
				}
				
				if (board[i][j] == 'X')
				{
					AssertExactlyTwoOrFourAdjacentXsOrAsOrBs(i, j);
				}
			}
		}
		
		if (intersectionPointCount != 2)
		{
			throw new Exception("Incorrect intersection point count");
		}
System.exit(42);
	}

	private static void AssertExactlyTwoAdjacentXs(int i, int j) throws Exception 
	{
		int xCount = 0;
		
		if (i > 0)
		{
			xCount += board[i - 1][j] == 'X' ? 1 : 0;
		}
		
		if (j > 0)
		{
			xCount += board[i][j - 1] == 'X' ? 1 : 0;
		}

		if (i < r - 1)
		{
			xCount += board[i + 1][j] == 'X' ? 1 : 0;
		}
		
		if (j < c - 1)
		{
			xCount += board[i][j + 1] == 'X' ? 1 : 0;
		}
		
		if (xCount != 2)
		{
			throw new Exception("Illegal number of Xs adjacent to an A or B");
		}
	}
	
	private static void AssertExactlyTwoOrFourAdjacentXsOrAsOrBs(int i, int j) throws Exception 
	{
		int xCount = 0;
		
		if (i > 0)
		{
			xCount += board[i - 1][j] == 'X' || board[i - 1][j] == 'A' || board[i - 1][j] == 'B' ? 1 : 0;
		}
		
		if (j > 0)
		{
			xCount += board[i][j - 1] == 'X' || board[i][j - 1] == 'A' || board[i][j - 1] == 'B' ? 1 : 0;
		}

		if (i < r - 1)
		{
			xCount += board[i + 1][j] == 'X' || board[i + 1][j] == 'A' || board[i + 1][j] == 'B' ? 1 : 0;
		}
		
		if (j < c - 1)
		{
			xCount += board[i][j + 1] == 'X' || board[i][j + 1] == 'A' || board[i][j + 1] == 'B' ? 1 : 0;
		}
		
		if (xCount != 2 && xCount != 4)
		{
			throw new Exception("Illegal number of Xs or As or Bs adjacent to an X at <" + i + ", " + j + ">");
		}
		
		if (xCount == 4)
		{
			intersectionPointCount++;
		}
	}
}
